e static method
Logs an error-level message.
Only prints when logging is enabled and the app is in debug mode.
Implementation
static void e(String text) {
if (_enableLogs) {
_printError(getFormattedText(text));
}
}
Logs an error-level message.
Only prints when logging is enabled and the app is in debug mode.
static void e(String text) {
if (_enableLogs) {
_printError(getFormattedText(text));
}
}